==> dde-network-core_1.0.64.orig.tar.xz: dde-network-core-1.0.64/dss-network-plugin/translations/dss-network-plugin_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS language="sq" version="2.1">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 mesazh i ri</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Po lidhet %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 u lidh</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 u shkëput</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>S’arrihet të lidhet %1, ju lutemi, kontrolloni rrugëzuesin tuaj ose kabllon e rrjetit.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>S’arrihet të lidhet %1, ju lutemi, jini pranë rrugëzuesit pa fill</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Lidhja dështoi, s’arrihet të lidhet %1, fjalëkalim i gabuar</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Fjalëkalimi është i domosdoshëm për t’u lidhur %1</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>Rrjeti %1 802.11 WLAN s’u gjet dot</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Lidhje Me Fill</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokoll</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Lloj Sigurie</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bandë</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Ndërfaqe</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>NetMask-ë</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Parësore</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Parashtesë</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Shpejtësi</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Pajisje e çaktivizuar</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>E lidhur, por pa hyrje Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Jo e lidhur</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kablloja e rrjetit është e hequr</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Po lidhet</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Po bëhet mirëfilltësim</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Po merret adresë IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>E lidhur</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>E shkëputur</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Përplasje IP-sh</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>U dështua</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Po merret adresë</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Rrjet Me Fill</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rrjet Me Fill %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rrjet Pa Fill</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rrjet Pa Fill %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Pajisje e çaktivizuar</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kablloja e rrjetit është e hequr</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Jo e lidhur</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Po lidhet</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>E lidhur, por pa hyrje Internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Lidhja dështoi</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Përplasje IP-sh</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Çaktivizo lidhje me fill</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Aktivizo lidhje me fill</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Çaktivizo lidhje pa fill</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Aktivizo lidhje pa fill</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Çaktivizo rrjetin</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Aktivizo rrjetin</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Rregullime rrjeti</translation>
    </message>
</context>
</TS>

==> dde-network-core_1.1.2.orig.tar.xz: dde-network-core-1.1.2/dss-network-plugin/translations/dss-network-plugin_sq.ts <==
<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="sq">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 mesazh i ri</translation>
    </message>
</context>
<context>
    <name>DeviceControllItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Rrjet Pa Fill</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rrjet Me Fill</translation>
    </message>
</context>
<context>
    <name>QObject</name>
    <message>
        <source>Connecting %1</source>
        <translation>Po lidhet %1</translation>
    </message>
    <message>
        <source>%1 connected</source>
        <translation>%1 u lidh</translation>
    </message>
    <message>
        <source>%1 disconnected</source>
        <translation>%1 u shkëput</translation>
    </message>
    <message>
        <source>Unable to connect %1, please check your router or net cable.</source>
        <translation>S’arrihet të lidhet %1, ju lutemi, kontrolloni rrugëzuesin tuaj ose kabllon e rrjetit.</translation>
    </message>
    <message>
        <source>Unable to connect %1, please keep closer to the wireless router</source>
        <translation>S’arrihet të lidhet %1, ju lutemi, jini pranë rrugëzuesit pa fill</translation>
    </message>
    <message>
        <source>Connection failed, unable to connect %1, wrong password</source>
        <translation>Lidhja dështoi, s’arrihet të lidhet %1, fjalëkalim i gabuar</translation>
    </message>
    <message>
        <source>Password is required to connect %1</source>
        <translation>Fjalëkalimi është i domosdoshëm për t’u lidhur %1</translation>
    </message>
    <message>
        <source>The %1 802.11 WLAN network could not be found</source>
        <translation>Rrjeti %1 802.11 WLAN s’u gjet dot</translation>
    </message>
</context>
<context>
    <name>WirelessItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Lidhu me rrjet të fshehur</translation>
    </message>
    <message>
        <source>Password</source>
        <translation>Fjalëkalim</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Anuloje</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Lidhu</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Emër (SSID)</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDetails</name>
    <message>
        <source>Hotspot</source>
        <translation>Hotspot</translation>
    </message>
    <message>
        <source>SSID</source>
        <translation>SSID</translation>
    </message>
    <message>
        <source>Protocol</source>
        <translation>Protokoll</translation>
    </message>
    <message>
        <source>Security Type</source>
        <translation>Lloj Sigurie</translation>
    </message>
    <message>
        <source>Channel</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Band</source>
        <translation>Bandë</translation>
    </message>
    <message>
        <source>Interface</source>
        <translation>Ndërfaqe</translation>
    </message>
    <message>
        <source>MAC</source>
        <translation>MAC</translation>
    </message>
    <message>
        <source>IPv4</source>
        <translation>IPv4</translation>
    </message>
    <message>
        <source>Netmask</source>
        <translation>NetMask-ë</translation>
    </message>
    <message>
        <source>Gateway</source>
        <translation>Kanal</translation>
    </message>
    <message>
        <source>Primary DNS</source>
        <translation>DNS Parësore</translation>
    </message>
    <message>
        <source>IPv6</source>
        <translation>IPv6</translation>
    </message>
    <message>
        <source>Prefix</source>
        <translation>Parashtesë</translation>
    </message>
    <message>
        <source>Speed</source>
        <translation>Shpejtësi</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkDeviceRealize</name>
    <message>
        <source>Device disabled</source>
        <translation>Pajisje e çaktivizuar</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>E lidhur, por pa hyrje Internet</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Jo e lidhur</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kablloja e rrjetit është e hequr</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Po lidhet</translation>
    </message>
    <message>
        <source>Authenticating</source>
        <translation>Po bëhet mirëfilltësim</translation>
    </message>
    <message>
        <source>Obtaining IP address</source>
        <translation>Po merret adresë IP</translation>
    </message>
    <message>
        <source>Connected</source>
        <translation>E lidhur</translation>
    </message>
    <message>
        <source>Disconnected</source>
        <translation>E shkëputur</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Përplasje IP-sh</translation>
    </message>
    <message>
        <source>Failed</source>
        <translation>U dështua</translation>
    </message>
    <message>
        <source>Obtaining address</source>
        <translation>Po merret adresë</translation>
    </message>
</context>
<context>
    <name>dde::network::NetworkProcesser</name>
    <message>
        <source>Wired Network</source>
        <translation>Rrjet Me Fill</translation>
    </message>
    <message>
        <source>Wired Network %1</source>
        <translation>Rrjet Me Fill %1</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rrjet Pa Fill</translation>
    </message>
    <message>
        <source>Wireless Network %1</source>
        <translation>Rrjet Pa Fill %1</translation>
    </message>
</context>
<context>
    <name>dde::networkplugin::NetworkPluginHelper</name>
    <message>
        <source>Device disabled</source>
        <translation>Pajisje e çaktivizuar</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Kablloja e rrjetit është e hequr</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Jo e lidhur</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Po lidhet</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>E lidhur, por pa hyrje Internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Lidhja dështoi</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Përplasje IP-sh</translation>
    </message>
    <message>
        <source>Disable wired connection</source>
        <translation>Çaktivizo lidhje me fill</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Aktivizo lidhje me fill</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Çaktivizo lidhje pa fill</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Aktivizo lidhje pa fill</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Çaktivizo rrjetin</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Aktivizo rrjetin</translation>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Rregullime rrjeti</translation>
    </message>
</context>
<context>
    <name>dss::module::NetworkModule</name>
    <message>
        <source>Wired Connection</source>
        <translation>Lidhje Me Fill</translation>
    </message>
</context>
</TS>
